//[mahjong-utils](../../index.md)/[mahjongutils.models](index.md)/[Tatsu](-tatsu.md)

# Tatsu

[common]\
fun [Tatsu](-tatsu.md)(first: [Tile](-tile/index.md), second: [Tile](-tile/index.md)): [Tatsu](-tatsu/index.md)

fun [Tatsu](-tatsu.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Tatsu](-tatsu/index.md)
